@@ -18,7 +18,8 @@ class LCAFNullAddress(LCAFAddress):
         super(LCAFNullAddress, self).sanitize()
 
     @classmethod
-    def _from_data_bytes(cls, data, prefix_len=None):
+    def _from_data_bytes(cls, data, prefix_len=None, rsvd1=None, flags=None,
+                         rsvd2=None):
         lcaf = cls()
         lcaf.sanitize()
         return lcaf
